"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PostgresqlConfig12_1C(google.protobuf.message.Message):
    """Options and structure of `PostgresqlConfig` reflects PostgreSQL configuration file
    parameters which detailed description is available in
    [PostgreSQL documentation](https://www.postgresql.org/docs/11/runtime-config.html).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _BackslashQuote:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BackslashQuoteEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._BackslashQuote.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BACKSLASH_QUOTE_UNSPECIFIED: PostgresqlConfig12_1C._BackslashQuote.ValueType  # 0
        BACKSLASH_QUOTE: PostgresqlConfig12_1C._BackslashQuote.ValueType  # 1
        """Quotation mark can be represented as \\' (same as on)."""
        BACKSLASH_QUOTE_ON: PostgresqlConfig12_1C._BackslashQuote.ValueType  # 2
        """Quotation mark can be represented as \\'."""
        BACKSLASH_QUOTE_OFF: PostgresqlConfig12_1C._BackslashQuote.ValueType  # 3
        """Quotation mark can only be represented using the standard SQL syntax ''."""
        BACKSLASH_QUOTE_SAFE_ENCODING: PostgresqlConfig12_1C._BackslashQuote.ValueType  # 4
        """Representing a quotation mark as \\' is only permitted for client encodings where \\ is not used for multibyte characters."""

    class BackslashQuote(_BackslashQuote, metaclass=_BackslashQuoteEnumTypeWrapper): ...
    BACKSLASH_QUOTE_UNSPECIFIED: PostgresqlConfig12_1C.BackslashQuote.ValueType  # 0
    BACKSLASH_QUOTE: PostgresqlConfig12_1C.BackslashQuote.ValueType  # 1
    """Quotation mark can be represented as \\' (same as on)."""
    BACKSLASH_QUOTE_ON: PostgresqlConfig12_1C.BackslashQuote.ValueType  # 2
    """Quotation mark can be represented as \\'."""
    BACKSLASH_QUOTE_OFF: PostgresqlConfig12_1C.BackslashQuote.ValueType  # 3
    """Quotation mark can only be represented using the standard SQL syntax ''."""
    BACKSLASH_QUOTE_SAFE_ENCODING: PostgresqlConfig12_1C.BackslashQuote.ValueType  # 4
    """Representing a quotation mark as \\' is only permitted for client encodings where \\ is not used for multibyte characters."""

    class _ByteaOutput:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ByteaOutputEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._ByteaOutput.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BYTEA_OUTPUT_UNSPECIFIED: PostgresqlConfig12_1C._ByteaOutput.ValueType  # 0
        BYTEA_OUTPUT_HEX: PostgresqlConfig12_1C._ByteaOutput.ValueType  # 1
        """Each byte is represented by two hexadecimal characters, e.g., 'SELECT '\\xDEADBEEF';'."""
        BYTEA_OUTPUT_ESCAPED: PostgresqlConfig12_1C._ByteaOutput.ValueType  # 2
        """Standard PostgreSQL format with ASCII characters only."""

    class ByteaOutput(_ByteaOutput, metaclass=_ByteaOutputEnumTypeWrapper): ...
    BYTEA_OUTPUT_UNSPECIFIED: PostgresqlConfig12_1C.ByteaOutput.ValueType  # 0
    BYTEA_OUTPUT_HEX: PostgresqlConfig12_1C.ByteaOutput.ValueType  # 1
    """Each byte is represented by two hexadecimal characters, e.g., 'SELECT '\\xDEADBEEF';'."""
    BYTEA_OUTPUT_ESCAPED: PostgresqlConfig12_1C.ByteaOutput.ValueType  # 2
    """Standard PostgreSQL format with ASCII characters only."""

    class _ConstraintExclusion:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ConstraintExclusionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._ConstraintExclusion.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CONSTRAINT_EXCLUSION_UNSPECIFIED: PostgresqlConfig12_1C._ConstraintExclusion.ValueType  # 0
        CONSTRAINT_EXCLUSION_ON: PostgresqlConfig12_1C._ConstraintExclusion.ValueType  # 1
        """Enable planner's use of constraints for all tables."""
        CONSTRAINT_EXCLUSION_OFF: PostgresqlConfig12_1C._ConstraintExclusion.ValueType  # 2
        """Disable planner's use of constraints for all tables"""
        CONSTRAINT_EXCLUSION_PARTITION: PostgresqlConfig12_1C._ConstraintExclusion.ValueType  # 3
        """Only use constraints for child tables and UNION ALL clauses."""

    class ConstraintExclusion(_ConstraintExclusion, metaclass=_ConstraintExclusionEnumTypeWrapper): ...
    CONSTRAINT_EXCLUSION_UNSPECIFIED: PostgresqlConfig12_1C.ConstraintExclusion.ValueType  # 0
    CONSTRAINT_EXCLUSION_ON: PostgresqlConfig12_1C.ConstraintExclusion.ValueType  # 1
    """Enable planner's use of constraints for all tables."""
    CONSTRAINT_EXCLUSION_OFF: PostgresqlConfig12_1C.ConstraintExclusion.ValueType  # 2
    """Disable planner's use of constraints for all tables"""
    CONSTRAINT_EXCLUSION_PARTITION: PostgresqlConfig12_1C.ConstraintExclusion.ValueType  # 3
    """Only use constraints for child tables and UNION ALL clauses."""

    class _ForceParallelMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ForceParallelModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._ForceParallelMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FORCE_PARALLEL_MODE_UNSPECIFIED: PostgresqlConfig12_1C._ForceParallelMode.ValueType  # 0
        FORCE_PARALLEL_MODE_ON: PostgresqlConfig12_1C._ForceParallelMode.ValueType  # 1
        """Force parallel mode for all queries that can be executed safely in parallel."""
        FORCE_PARALLEL_MODE_OFF: PostgresqlConfig12_1C._ForceParallelMode.ValueType  # 2
        """Enable parallel mode only if it is expected to increase performance."""
        FORCE_PARALLEL_MODE_REGRESS: PostgresqlConfig12_1C._ForceParallelMode.ValueType  # 3
        """Equivalent to on, but generates output identical to the off state."""

    class ForceParallelMode(_ForceParallelMode, metaclass=_ForceParallelModeEnumTypeWrapper): ...
    FORCE_PARALLEL_MODE_UNSPECIFIED: PostgresqlConfig12_1C.ForceParallelMode.ValueType  # 0
    FORCE_PARALLEL_MODE_ON: PostgresqlConfig12_1C.ForceParallelMode.ValueType  # 1
    """Force parallel mode for all queries that can be executed safely in parallel."""
    FORCE_PARALLEL_MODE_OFF: PostgresqlConfig12_1C.ForceParallelMode.ValueType  # 2
    """Enable parallel mode only if it is expected to increase performance."""
    FORCE_PARALLEL_MODE_REGRESS: PostgresqlConfig12_1C.ForceParallelMode.ValueType  # 3
    """Equivalent to on, but generates output identical to the off state."""

    class _LogErrorVerbosity:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogErrorVerbosityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._LogErrorVerbosity.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_ERROR_VERBOSITY_UNSPECIFIED: PostgresqlConfig12_1C._LogErrorVerbosity.ValueType  # 0
        LOG_ERROR_VERBOSITY_TERSE: PostgresqlConfig12_1C._LogErrorVerbosity.ValueType  # 1
        """DETAIL, HINT, QUERY, and CONTEXT fields are excluded from the error message."""
        LOG_ERROR_VERBOSITY_DEFAULT: PostgresqlConfig12_1C._LogErrorVerbosity.ValueType  # 2
        """Default."""
        LOG_ERROR_VERBOSITY_VERBOSE: PostgresqlConfig12_1C._LogErrorVerbosity.ValueType  # 3
        """Error message includes the SQLSTATE error code, source filename, function name, and the line number where the error occurred."""

    class LogErrorVerbosity(_LogErrorVerbosity, metaclass=_LogErrorVerbosityEnumTypeWrapper): ...
    LOG_ERROR_VERBOSITY_UNSPECIFIED: PostgresqlConfig12_1C.LogErrorVerbosity.ValueType  # 0
    LOG_ERROR_VERBOSITY_TERSE: PostgresqlConfig12_1C.LogErrorVerbosity.ValueType  # 1
    """DETAIL, HINT, QUERY, and CONTEXT fields are excluded from the error message."""
    LOG_ERROR_VERBOSITY_DEFAULT: PostgresqlConfig12_1C.LogErrorVerbosity.ValueType  # 2
    """Default."""
    LOG_ERROR_VERBOSITY_VERBOSE: PostgresqlConfig12_1C.LogErrorVerbosity.ValueType  # 3
    """Error message includes the SQLSTATE error code, source filename, function name, and the line number where the error occurred."""

    class _LogLevel:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._LogLevel.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_LEVEL_UNSPECIFIED: PostgresqlConfig12_1C._LogLevel.ValueType  # 0
        LOG_LEVEL_DEBUG5: PostgresqlConfig12_1C._LogLevel.ValueType  # 1
        """Provides successively-more-detailed information for use by developers."""
        LOG_LEVEL_DEBUG4: PostgresqlConfig12_1C._LogLevel.ValueType  # 2
        """Provides successively-more-detailed information for use by developers."""
        LOG_LEVEL_DEBUG3: PostgresqlConfig12_1C._LogLevel.ValueType  # 3
        """Provides successively-more-detailed information for use by developers."""
        LOG_LEVEL_DEBUG2: PostgresqlConfig12_1C._LogLevel.ValueType  # 4
        """Provides successively-more-detailed information for use by developers."""
        LOG_LEVEL_DEBUG1: PostgresqlConfig12_1C._LogLevel.ValueType  # 5
        """Provides successively-more-detailed information for use by developers."""
        LOG_LEVEL_LOG: PostgresqlConfig12_1C._LogLevel.ValueType  # 6
        """Reports information of interest to administrators, e.g., checkpoint activity."""
        LOG_LEVEL_NOTICE: PostgresqlConfig12_1C._LogLevel.ValueType  # 7
        """Provides information that might be helpful to users, e.g., notice of truncation of long identifiers."""
        LOG_LEVEL_WARNING: PostgresqlConfig12_1C._LogLevel.ValueType  # 8
        """Provides warnings of likely problems, e.g., COMMIT outside a transaction block."""
        LOG_LEVEL_ERROR: PostgresqlConfig12_1C._LogLevel.ValueType  # 9
        """Reports an error that caused the current command to abort."""
        LOG_LEVEL_FATAL: PostgresqlConfig12_1C._LogLevel.ValueType  # 10
        """Reports an error that caused the current session to abort."""
        LOG_LEVEL_PANIC: PostgresqlConfig12_1C._LogLevel.ValueType  # 11
        """Reports an error that caused all database sessions to abort."""

    class LogLevel(_LogLevel, metaclass=_LogLevelEnumTypeWrapper): ...
    LOG_LEVEL_UNSPECIFIED: PostgresqlConfig12_1C.LogLevel.ValueType  # 0
    LOG_LEVEL_DEBUG5: PostgresqlConfig12_1C.LogLevel.ValueType  # 1
    """Provides successively-more-detailed information for use by developers."""
    LOG_LEVEL_DEBUG4: PostgresqlConfig12_1C.LogLevel.ValueType  # 2
    """Provides successively-more-detailed information for use by developers."""
    LOG_LEVEL_DEBUG3: PostgresqlConfig12_1C.LogLevel.ValueType  # 3
    """Provides successively-more-detailed information for use by developers."""
    LOG_LEVEL_DEBUG2: PostgresqlConfig12_1C.LogLevel.ValueType  # 4
    """Provides successively-more-detailed information for use by developers."""
    LOG_LEVEL_DEBUG1: PostgresqlConfig12_1C.LogLevel.ValueType  # 5
    """Provides successively-more-detailed information for use by developers."""
    LOG_LEVEL_LOG: PostgresqlConfig12_1C.LogLevel.ValueType  # 6
    """Reports information of interest to administrators, e.g., checkpoint activity."""
    LOG_LEVEL_NOTICE: PostgresqlConfig12_1C.LogLevel.ValueType  # 7
    """Provides information that might be helpful to users, e.g., notice of truncation of long identifiers."""
    LOG_LEVEL_WARNING: PostgresqlConfig12_1C.LogLevel.ValueType  # 8
    """Provides warnings of likely problems, e.g., COMMIT outside a transaction block."""
    LOG_LEVEL_ERROR: PostgresqlConfig12_1C.LogLevel.ValueType  # 9
    """Reports an error that caused the current command to abort."""
    LOG_LEVEL_FATAL: PostgresqlConfig12_1C.LogLevel.ValueType  # 10
    """Reports an error that caused the current session to abort."""
    LOG_LEVEL_PANIC: PostgresqlConfig12_1C.LogLevel.ValueType  # 11
    """Reports an error that caused all database sessions to abort."""

    class _LogStatement:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogStatementEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._LogStatement.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_STATEMENT_UNSPECIFIED: PostgresqlConfig12_1C._LogStatement.ValueType  # 0
        LOG_STATEMENT_NONE: PostgresqlConfig12_1C._LogStatement.ValueType  # 1
        """The filter is disabled, no SQL statements are logged."""
        LOG_STATEMENT_DDL: PostgresqlConfig12_1C._LogStatement.ValueType  # 2
        """System logs DDL statements, e.g., CREATE, ALTER, DROP etc."""
        LOG_STATEMENT_MOD: PostgresqlConfig12_1C._LogStatement.ValueType  # 3
        """System logs ddl-statements along with data modification commands, e.g., INSERT, UPDATE, etc."""
        LOG_STATEMENT_ALL: PostgresqlConfig12_1C._LogStatement.ValueType  # 4
        """System logs all SQL statements."""

    class LogStatement(_LogStatement, metaclass=_LogStatementEnumTypeWrapper): ...
    LOG_STATEMENT_UNSPECIFIED: PostgresqlConfig12_1C.LogStatement.ValueType  # 0
    LOG_STATEMENT_NONE: PostgresqlConfig12_1C.LogStatement.ValueType  # 1
    """The filter is disabled, no SQL statements are logged."""
    LOG_STATEMENT_DDL: PostgresqlConfig12_1C.LogStatement.ValueType  # 2
    """System logs DDL statements, e.g., CREATE, ALTER, DROP etc."""
    LOG_STATEMENT_MOD: PostgresqlConfig12_1C.LogStatement.ValueType  # 3
    """System logs ddl-statements along with data modification commands, e.g., INSERT, UPDATE, etc."""
    LOG_STATEMENT_ALL: PostgresqlConfig12_1C.LogStatement.ValueType  # 4
    """System logs all SQL statements."""

    class _PasswordEncryption:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PasswordEncryptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._PasswordEncryption.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PASSWORD_ENCRYPTION_UNSPECIFIED: PostgresqlConfig12_1C._PasswordEncryption.ValueType  # 0
        PASSWORD_ENCRYPTION_MD5: PostgresqlConfig12_1C._PasswordEncryption.ValueType  # 1
        """The method md5 uses a custom less secure challenge-response mechanism. It prevents password sniffing and avoids storing passwords on the server in plain text but provides no protection if an attacker manages to steal the password hash from the server. Also, the MD5 hash algorithm is nowadays no longer considered secure against determined attacks."""
        PASSWORD_ENCRYPTION_SCRAM_SHA_256: PostgresqlConfig12_1C._PasswordEncryption.ValueType  # 2
        """The method scram-sha-256 performs SCRAM-SHA-256 authentication, as described in RFC 7677. It is a challenge-response scheme that prevents password sniffing on untrusted connections and supports storing passwords on the server in a cryptographically hashed form that is thought to be secure.
        This is the most secure of the currently provided methods, but it is not supported by older client libraries.
        """

    class PasswordEncryption(_PasswordEncryption, metaclass=_PasswordEncryptionEnumTypeWrapper): ...
    PASSWORD_ENCRYPTION_UNSPECIFIED: PostgresqlConfig12_1C.PasswordEncryption.ValueType  # 0
    PASSWORD_ENCRYPTION_MD5: PostgresqlConfig12_1C.PasswordEncryption.ValueType  # 1
    """The method md5 uses a custom less secure challenge-response mechanism. It prevents password sniffing and avoids storing passwords on the server in plain text but provides no protection if an attacker manages to steal the password hash from the server. Also, the MD5 hash algorithm is nowadays no longer considered secure against determined attacks."""
    PASSWORD_ENCRYPTION_SCRAM_SHA_256: PostgresqlConfig12_1C.PasswordEncryption.ValueType  # 2
    """The method scram-sha-256 performs SCRAM-SHA-256 authentication, as described in RFC 7677. It is a challenge-response scheme that prevents password sniffing on untrusted connections and supports storing passwords on the server in a cryptographically hashed form that is thought to be secure.
    This is the most secure of the currently provided methods, but it is not supported by older client libraries.
    """

    class _PgHintPlanDebugPrint:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PgHintPlanDebugPrintEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._PgHintPlanDebugPrint.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PG_HINT_PLAN_DEBUG_PRINT_UNSPECIFIED: PostgresqlConfig12_1C._PgHintPlanDebugPrint.ValueType  # 0
        PG_HINT_PLAN_DEBUG_PRINT_OFF: PostgresqlConfig12_1C._PgHintPlanDebugPrint.ValueType  # 1
        """Disable debug output"""
        PG_HINT_PLAN_DEBUG_PRINT_ON: PostgresqlConfig12_1C._PgHintPlanDebugPrint.ValueType  # 2
        """Print debug messages about hint parsing"""
        PG_HINT_PLAN_DEBUG_PRINT_DETAILED: PostgresqlConfig12_1C._PgHintPlanDebugPrint.ValueType  # 3
        """Print detailed debug information including query planning process"""
        PG_HINT_PLAN_DEBUG_PRINT_VERBOSE: PostgresqlConfig12_1C._PgHintPlanDebugPrint.ValueType  # 4
        """Print verbose debug output with all internal operations"""

    class PgHintPlanDebugPrint(_PgHintPlanDebugPrint, metaclass=_PgHintPlanDebugPrintEnumTypeWrapper): ...
    PG_HINT_PLAN_DEBUG_PRINT_UNSPECIFIED: PostgresqlConfig12_1C.PgHintPlanDebugPrint.ValueType  # 0
    PG_HINT_PLAN_DEBUG_PRINT_OFF: PostgresqlConfig12_1C.PgHintPlanDebugPrint.ValueType  # 1
    """Disable debug output"""
    PG_HINT_PLAN_DEBUG_PRINT_ON: PostgresqlConfig12_1C.PgHintPlanDebugPrint.ValueType  # 2
    """Print debug messages about hint parsing"""
    PG_HINT_PLAN_DEBUG_PRINT_DETAILED: PostgresqlConfig12_1C.PgHintPlanDebugPrint.ValueType  # 3
    """Print detailed debug information including query planning process"""
    PG_HINT_PLAN_DEBUG_PRINT_VERBOSE: PostgresqlConfig12_1C.PgHintPlanDebugPrint.ValueType  # 4
    """Print verbose debug output with all internal operations"""

    class _PlanCacheMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PlanCacheModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._PlanCacheMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PLAN_CACHE_MODE_UNSPECIFIED: PostgresqlConfig12_1C._PlanCacheMode.ValueType  # 0
        PLAN_CACHE_MODE_AUTO: PostgresqlConfig12_1C._PlanCacheMode.ValueType  # 1
        """Automatic selection."""
        PLAN_CACHE_MODE_FORCE_CUSTOM_PLAN: PostgresqlConfig12_1C._PlanCacheMode.ValueType  # 2
        """Forces the use of custom plans."""
        PLAN_CACHE_MODE_FORCE_GENERIC_PLAN: PostgresqlConfig12_1C._PlanCacheMode.ValueType  # 3
        """Forces the use of generic plans."""

    class PlanCacheMode(_PlanCacheMode, metaclass=_PlanCacheModeEnumTypeWrapper): ...
    PLAN_CACHE_MODE_UNSPECIFIED: PostgresqlConfig12_1C.PlanCacheMode.ValueType  # 0
    PLAN_CACHE_MODE_AUTO: PostgresqlConfig12_1C.PlanCacheMode.ValueType  # 1
    """Automatic selection."""
    PLAN_CACHE_MODE_FORCE_CUSTOM_PLAN: PostgresqlConfig12_1C.PlanCacheMode.ValueType  # 2
    """Forces the use of custom plans."""
    PLAN_CACHE_MODE_FORCE_GENERIC_PLAN: PostgresqlConfig12_1C.PlanCacheMode.ValueType  # 3
    """Forces the use of generic plans."""

    class _SharedPreloadLibraries:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SharedPreloadLibrariesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._SharedPreloadLibraries.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SHARED_PRELOAD_LIBRARIES_UNSPECIFIED: PostgresqlConfig12_1C._SharedPreloadLibraries.ValueType  # 0
        SHARED_PRELOAD_LIBRARIES_AUTO_EXPLAIN: PostgresqlConfig12_1C._SharedPreloadLibraries.ValueType  # 1
        """Required for the [auto_explain](https://www.postgresql.org/docs/current/auto-explain.html) extension."""
        SHARED_PRELOAD_LIBRARIES_PG_HINT_PLAN: PostgresqlConfig12_1C._SharedPreloadLibraries.ValueType  # 2
        """Required for the [pg_hint_plan](https://github.com/ossc-db/pg_hint_plan) extension."""
        SHARED_PRELOAD_LIBRARIES_TIMESCALEDB: PostgresqlConfig12_1C._SharedPreloadLibraries.ValueType  # 3
        """Required for [TimescaleDB](https://github.com/timescale/timescaledb) to function."""
        SHARED_PRELOAD_LIBRARIES_PG_QUALSTATS: PostgresqlConfig12_1C._SharedPreloadLibraries.ValueType  # 4
        """Required for the [pg_qualstats](https://github.com/powa-team/pg_qualstats) extension."""
        SHARED_PRELOAD_LIBRARIES_PG_CRON: PostgresqlConfig12_1C._SharedPreloadLibraries.ValueType  # 5
        """Required for the [pg_cron](https://github.com/citusdata/pg_cron) extension."""
        SHARED_PRELOAD_LIBRARIES_PGLOGICAL: PostgresqlConfig12_1C._SharedPreloadLibraries.ValueType  # 6
        """Required for the [pglogical](https://github.com/2ndQuadrant/pglogical) extension."""
        SHARED_PRELOAD_LIBRARIES_PG_PREWARM: PostgresqlConfig12_1C._SharedPreloadLibraries.ValueType  # 7
        """Shared library of extension [pg_prewarm](https://www.postgresql.org/docs/current/pgprewarm.html#PGPREWARM), which ensures loading of extension on server start"""
        SHARED_PRELOAD_LIBRARIES_PGAUDIT: PostgresqlConfig12_1C._SharedPreloadLibraries.ValueType  # 8
        """Required for the [pgaudit](https://www.pgaudit.org/) extension."""

    class SharedPreloadLibraries(_SharedPreloadLibraries, metaclass=_SharedPreloadLibrariesEnumTypeWrapper): ...
    SHARED_PRELOAD_LIBRARIES_UNSPECIFIED: PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType  # 0
    SHARED_PRELOAD_LIBRARIES_AUTO_EXPLAIN: PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType  # 1
    """Required for the [auto_explain](https://www.postgresql.org/docs/current/auto-explain.html) extension."""
    SHARED_PRELOAD_LIBRARIES_PG_HINT_PLAN: PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType  # 2
    """Required for the [pg_hint_plan](https://github.com/ossc-db/pg_hint_plan) extension."""
    SHARED_PRELOAD_LIBRARIES_TIMESCALEDB: PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType  # 3
    """Required for [TimescaleDB](https://github.com/timescale/timescaledb) to function."""
    SHARED_PRELOAD_LIBRARIES_PG_QUALSTATS: PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType  # 4
    """Required for the [pg_qualstats](https://github.com/powa-team/pg_qualstats) extension."""
    SHARED_PRELOAD_LIBRARIES_PG_CRON: PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType  # 5
    """Required for the [pg_cron](https://github.com/citusdata/pg_cron) extension."""
    SHARED_PRELOAD_LIBRARIES_PGLOGICAL: PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType  # 6
    """Required for the [pglogical](https://github.com/2ndQuadrant/pglogical) extension."""
    SHARED_PRELOAD_LIBRARIES_PG_PREWARM: PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType  # 7
    """Shared library of extension [pg_prewarm](https://www.postgresql.org/docs/current/pgprewarm.html#PGPREWARM), which ensures loading of extension on server start"""
    SHARED_PRELOAD_LIBRARIES_PGAUDIT: PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType  # 8
    """Required for the [pgaudit](https://www.pgaudit.org/) extension."""

    class _SynchronousCommit:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SynchronousCommitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._SynchronousCommit.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SYNCHRONOUS_COMMIT_UNSPECIFIED: PostgresqlConfig12_1C._SynchronousCommit.ValueType  # 0
        SYNCHRONOUS_COMMIT_ON: PostgresqlConfig12_1C._SynchronousCommit.ValueType  # 1
        """Success is reported to the client if the data is in WAL (Write-Ahead Log), and WAL is written to the storage of both the master and its synchronous standby server. Default value."""
        SYNCHRONOUS_COMMIT_OFF: PostgresqlConfig12_1C._SynchronousCommit.ValueType  # 2
        """Success is reported to the client even if the data is not in WAL.
        There is no synchronous write operation, data may be loss in case of storage subsystem failure.
        """
        SYNCHRONOUS_COMMIT_LOCAL: PostgresqlConfig12_1C._SynchronousCommit.ValueType  # 3
        """Success is reported to the client if the data is in WAL, and WAL is written to the storage of the master server.
        The transaction may be lost due to storage subsystem failure on the master server.
        """
        SYNCHRONOUS_COMMIT_REMOTE_WRITE: PostgresqlConfig12_1C._SynchronousCommit.ValueType  # 4
        """Success is reported to the client if the data is in WAL, WAL is written to the storage of the master server, and the server's synchronous standby indicates that it has received WAL and written it out to its operating system.
        The transaction may be lost due to simultaneous storage subsystem failure on the master and operating system's failure on the synchronous standby.
        """
        SYNCHRONOUS_COMMIT_REMOTE_APPLY: PostgresqlConfig12_1C._SynchronousCommit.ValueType  # 5
        """Success is reported to the client if the data is in WAL (Write-Ahead Log), WAL is written to the storage of the master server, and its synchronous standby indicates that it has received WAL and applied it.
        The transaction may be lost due to irrecoverably failure of both the master and its synchronous standby.
        """

    class SynchronousCommit(_SynchronousCommit, metaclass=_SynchronousCommitEnumTypeWrapper): ...
    SYNCHRONOUS_COMMIT_UNSPECIFIED: PostgresqlConfig12_1C.SynchronousCommit.ValueType  # 0
    SYNCHRONOUS_COMMIT_ON: PostgresqlConfig12_1C.SynchronousCommit.ValueType  # 1
    """Success is reported to the client if the data is in WAL (Write-Ahead Log), and WAL is written to the storage of both the master and its synchronous standby server. Default value."""
    SYNCHRONOUS_COMMIT_OFF: PostgresqlConfig12_1C.SynchronousCommit.ValueType  # 2
    """Success is reported to the client even if the data is not in WAL.
    There is no synchronous write operation, data may be loss in case of storage subsystem failure.
    """
    SYNCHRONOUS_COMMIT_LOCAL: PostgresqlConfig12_1C.SynchronousCommit.ValueType  # 3
    """Success is reported to the client if the data is in WAL, and WAL is written to the storage of the master server.
    The transaction may be lost due to storage subsystem failure on the master server.
    """
    SYNCHRONOUS_COMMIT_REMOTE_WRITE: PostgresqlConfig12_1C.SynchronousCommit.ValueType  # 4
    """Success is reported to the client if the data is in WAL, WAL is written to the storage of the master server, and the server's synchronous standby indicates that it has received WAL and written it out to its operating system.
    The transaction may be lost due to simultaneous storage subsystem failure on the master and operating system's failure on the synchronous standby.
    """
    SYNCHRONOUS_COMMIT_REMOTE_APPLY: PostgresqlConfig12_1C.SynchronousCommit.ValueType  # 5
    """Success is reported to the client if the data is in WAL (Write-Ahead Log), WAL is written to the storage of the master server, and its synchronous standby indicates that it has received WAL and applied it.
    The transaction may be lost due to irrecoverably failure of both the master and its synchronous standby.
    """

    class _TransactionIsolation:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TransactionIsolationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._TransactionIsolation.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TRANSACTION_ISOLATION_UNSPECIFIED: PostgresqlConfig12_1C._TransactionIsolation.ValueType  # 0
        TRANSACTION_ISOLATION_READ_UNCOMMITTED: PostgresqlConfig12_1C._TransactionIsolation.ValueType  # 1
        """This level behaves like `TRANSACTION_ISOLATION_READ_COMMITTED` in PostgreSQL."""
        TRANSACTION_ISOLATION_READ_COMMITTED: PostgresqlConfig12_1C._TransactionIsolation.ValueType  # 2
        """On this level query sees only data committed before the query began."""
        TRANSACTION_ISOLATION_REPEATABLE_READ: PostgresqlConfig12_1C._TransactionIsolation.ValueType  # 3
        """On this level all subsequent queries in a transaction will see the same rows, that were read by the first `SELECT` or `INSERT` query in this transaction, unchanged (these rows are locked during the first query)."""
        TRANSACTION_ISOLATION_SERIALIZABLE: PostgresqlConfig12_1C._TransactionIsolation.ValueType  # 4
        """This level provides the strictest transaction isolation.
        All queries in the current transaction see only the rows that were fixed prior to execution of the first `SELECT` or `INSERT` query in this transaction.
        If read and write operations in a concurrent set of serializable transactions overlap and this may cause an inconsistency that is not possible during the serial transaction execution, then one of the transaction will be rolled back, triggering a serialization failure.
        """

    class TransactionIsolation(_TransactionIsolation, metaclass=_TransactionIsolationEnumTypeWrapper): ...
    TRANSACTION_ISOLATION_UNSPECIFIED: PostgresqlConfig12_1C.TransactionIsolation.ValueType  # 0
    TRANSACTION_ISOLATION_READ_UNCOMMITTED: PostgresqlConfig12_1C.TransactionIsolation.ValueType  # 1
    """This level behaves like `TRANSACTION_ISOLATION_READ_COMMITTED` in PostgreSQL."""
    TRANSACTION_ISOLATION_READ_COMMITTED: PostgresqlConfig12_1C.TransactionIsolation.ValueType  # 2
    """On this level query sees only data committed before the query began."""
    TRANSACTION_ISOLATION_REPEATABLE_READ: PostgresqlConfig12_1C.TransactionIsolation.ValueType  # 3
    """On this level all subsequent queries in a transaction will see the same rows, that were read by the first `SELECT` or `INSERT` query in this transaction, unchanged (these rows are locked during the first query)."""
    TRANSACTION_ISOLATION_SERIALIZABLE: PostgresqlConfig12_1C.TransactionIsolation.ValueType  # 4
    """This level provides the strictest transaction isolation.
    All queries in the current transaction see only the rows that were fixed prior to execution of the first `SELECT` or `INSERT` query in this transaction.
    If read and write operations in a concurrent set of serializable transactions overlap and this may cause an inconsistency that is not possible during the serial transaction execution, then one of the transaction will be rolled back, triggering a serialization failure.
    """

    class _WalLevel:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _WalLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._WalLevel.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        WAL_LEVEL_UNSPECIFIED: PostgresqlConfig12_1C._WalLevel.ValueType  # 0
        WAL_LEVEL_REPLICA: PostgresqlConfig12_1C._WalLevel.ValueType  # 1
        """Supports WAL archiving and physical replication."""
        WAL_LEVEL_LOGICAL: PostgresqlConfig12_1C._WalLevel.ValueType  # 2
        """Supports WAL archiving, physical replication, and logical decoding."""

    class WalLevel(_WalLevel, metaclass=_WalLevelEnumTypeWrapper): ...
    WAL_LEVEL_UNSPECIFIED: PostgresqlConfig12_1C.WalLevel.ValueType  # 0
    WAL_LEVEL_REPLICA: PostgresqlConfig12_1C.WalLevel.ValueType  # 1
    """Supports WAL archiving and physical replication."""
    WAL_LEVEL_LOGICAL: PostgresqlConfig12_1C.WalLevel.ValueType  # 2
    """Supports WAL archiving, physical replication, and logical decoding."""

    class _XmlBinary:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _XmlBinaryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._XmlBinary.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        XML_BINARY_UNSPECIFIED: PostgresqlConfig12_1C._XmlBinary.ValueType  # 0
        XML_BINARY_BASE64: PostgresqlConfig12_1C._XmlBinary.ValueType  # 1
        """Base64 encoding."""
        XML_BINARY_HEX: PostgresqlConfig12_1C._XmlBinary.ValueType  # 2
        """Hexadecimal encoding."""

    class XmlBinary(_XmlBinary, metaclass=_XmlBinaryEnumTypeWrapper): ...
    XML_BINARY_UNSPECIFIED: PostgresqlConfig12_1C.XmlBinary.ValueType  # 0
    XML_BINARY_BASE64: PostgresqlConfig12_1C.XmlBinary.ValueType  # 1
    """Base64 encoding."""
    XML_BINARY_HEX: PostgresqlConfig12_1C.XmlBinary.ValueType  # 2
    """Hexadecimal encoding."""

    class _XmlOption:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _XmlOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig12_1C._XmlOption.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        XML_OPTION_UNSPECIFIED: PostgresqlConfig12_1C._XmlOption.ValueType  # 0
        XML_OPTION_DOCUMENT: PostgresqlConfig12_1C._XmlOption.ValueType  # 1
        """XML document."""
        XML_OPTION_CONTENT: PostgresqlConfig12_1C._XmlOption.ValueType  # 2
        """XML fragment."""

    class XmlOption(_XmlOption, metaclass=_XmlOptionEnumTypeWrapper): ...
    XML_OPTION_UNSPECIFIED: PostgresqlConfig12_1C.XmlOption.ValueType  # 0
    XML_OPTION_DOCUMENT: PostgresqlConfig12_1C.XmlOption.ValueType  # 1
    """XML document."""
    XML_OPTION_CONTENT: PostgresqlConfig12_1C.XmlOption.ValueType  # 2
    """XML fragment."""

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    TEMP_BUFFERS_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    WORK_MEM_FIELD_NUMBER: builtins.int
    MAINTENANCE_WORK_MEM_FIELD_NUMBER: builtins.int
    AUTOVACUUM_WORK_MEM_FIELD_NUMBER: builtins.int
    TEMP_FILE_LIMIT_FIELD_NUMBER: builtins.int
    VACUUM_COST_DELAY_FIELD_NUMBER: builtins.int
    VACUUM_COST_PAGE_HIT_FIELD_NUMBER: builtins.int
    VACUUM_COST_PAGE_MISS_FIELD_NUMBER: builtins.int
    VACUUM_COST_PAGE_DIRTY_FIELD_NUMBER: builtins.int
    VACUUM_COST_LIMIT_FIELD_NUMBER: builtins.int
    BGWRITER_DELAY_FIELD_NUMBER: builtins.int
    BGWRITER_LRU_MAXPAGES_FIELD_NUMBER: builtins.int
    BGWRITER_LRU_MULTIPLIER_FIELD_NUMBER: builtins.int
    BGWRITER_FLUSH_AFTER_FIELD_NUMBER: builtins.int
    BACKEND_FLUSH_AFTER_FIELD_NUMBER: builtins.int
    OLD_SNAPSHOT_THRESHOLD_FIELD_NUMBER: builtins.int
    WAL_LEVEL_FIELD_NUMBER: builtins.int
    SYNCHRONOUS_COMMIT_FIELD_NUMBER: builtins.int
    CHECKPOINT_TIMEOUT_FIELD_NUMBER: builtins.int
    CHECKPOINT_COMPLETION_TARGET_FIELD_NUMBER: builtins.int
    CHECKPOINT_FLUSH_AFTER_FIELD_NUMBER: builtins.int
    MAX_WAL_SIZE_FIELD_NUMBER: builtins.int
    MIN_WAL_SIZE_FIELD_NUMBER: builtins.int
    MAX_STANDBY_STREAMING_DELAY_FIELD_NUMBER: builtins.int
    DEFAULT_STATISTICS_TARGET_FIELD_NUMBER: builtins.int
    CONSTRAINT_EXCLUSION_FIELD_NUMBER: builtins.int
    CURSOR_TUPLE_FRACTION_FIELD_NUMBER: builtins.int
    FROM_COLLAPSE_LIMIT_FIELD_NUMBER: builtins.int
    JOIN_COLLAPSE_LIMIT_FIELD_NUMBER: builtins.int
    FORCE_PARALLEL_MODE_FIELD_NUMBER: builtins.int
    CLIENT_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    LOG_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    LOG_MIN_ERROR_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_MIN_DURATION_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_CHECKPOINTS_FIELD_NUMBER: builtins.int
    LOG_CONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DISCONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DURATION_FIELD_NUMBER: builtins.int
    LOG_ERROR_VERBOSITY_FIELD_NUMBER: builtins.int
    LOG_LOCK_WAITS_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_TEMP_FILES_FIELD_NUMBER: builtins.int
    SEARCH_PATH_FIELD_NUMBER: builtins.int
    ROW_SECURITY_FIELD_NUMBER: builtins.int
    DEFAULT_TRANSACTION_ISOLATION_FIELD_NUMBER: builtins.int
    STATEMENT_TIMEOUT_FIELD_NUMBER: builtins.int
    LOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    BYTEA_OUTPUT_FIELD_NUMBER: builtins.int
    XMLBINARY_FIELD_NUMBER: builtins.int
    XMLOPTION_FIELD_NUMBER: builtins.int
    GIN_PENDING_LIST_LIMIT_FIELD_NUMBER: builtins.int
    DEADLOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    MAX_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    MAX_PRED_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    ARRAY_NULLS_FIELD_NUMBER: builtins.int
    BACKSLASH_QUOTE_FIELD_NUMBER: builtins.int
    DEFAULT_WITH_OIDS_FIELD_NUMBER: builtins.int
    ESCAPE_STRING_WARNING_FIELD_NUMBER: builtins.int
    LO_COMPAT_PRIVILEGES_FIELD_NUMBER: builtins.int
    OPERATOR_PRECEDENCE_WARNING_FIELD_NUMBER: builtins.int
    QUOTE_ALL_IDENTIFIERS_FIELD_NUMBER: builtins.int
    STANDARD_CONFORMING_STRINGS_FIELD_NUMBER: builtins.int
    SYNCHRONIZE_SEQSCANS_FIELD_NUMBER: builtins.int
    TRANSFORM_NULL_EQUALS_FIELD_NUMBER: builtins.int
    EXIT_ON_ERROR_FIELD_NUMBER: builtins.int
    SEQ_PAGE_COST_FIELD_NUMBER: builtins.int
    RANDOM_PAGE_COST_FIELD_NUMBER: builtins.int
    AUTOVACUUM_MAX_WORKERS_FIELD_NUMBER: builtins.int
    AUTOVACUUM_VACUUM_COST_DELAY_FIELD_NUMBER: builtins.int
    AUTOVACUUM_VACUUM_COST_LIMIT_FIELD_NUMBER: builtins.int
    AUTOVACUUM_NAPTIME_FIELD_NUMBER: builtins.int
    ARCHIVE_TIMEOUT_FIELD_NUMBER: builtins.int
    TRACK_ACTIVITY_QUERY_SIZE_FIELD_NUMBER: builtins.int
    ONLINE_ANALYZE_ENABLE_FIELD_NUMBER: builtins.int
    ENABLE_BITMAPSCAN_FIELD_NUMBER: builtins.int
    ENABLE_HASHAGG_FIELD_NUMBER: builtins.int
    ENABLE_HASHJOIN_FIELD_NUMBER: builtins.int
    ENABLE_INDEXSCAN_FIELD_NUMBER: builtins.int
    ENABLE_INDEXONLYSCAN_FIELD_NUMBER: builtins.int
    ENABLE_MATERIAL_FIELD_NUMBER: builtins.int
    ENABLE_MERGEJOIN_FIELD_NUMBER: builtins.int
    ENABLE_NESTLOOP_FIELD_NUMBER: builtins.int
    ENABLE_SEQSCAN_FIELD_NUMBER: builtins.int
    ENABLE_SORT_FIELD_NUMBER: builtins.int
    ENABLE_TIDSCAN_FIELD_NUMBER: builtins.int
    MAX_WORKER_PROCESSES_FIELD_NUMBER: builtins.int
    MAX_PARALLEL_WORKERS_FIELD_NUMBER: builtins.int
    MAX_PARALLEL_WORKERS_PER_GATHER_FIELD_NUMBER: builtins.int
    AUTOVACUUM_VACUUM_SCALE_FACTOR_FIELD_NUMBER: builtins.int
    AUTOVACUUM_ANALYZE_SCALE_FACTOR_FIELD_NUMBER: builtins.int
    DEFAULT_TRANSACTION_READ_ONLY_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    ENABLE_PARALLEL_APPEND_FIELD_NUMBER: builtins.int
    ENABLE_PARALLEL_HASH_FIELD_NUMBER: builtins.int
    ENABLE_PARTITION_PRUNING_FIELD_NUMBER: builtins.int
    ENABLE_PARTITIONWISE_AGGREGATE_FIELD_NUMBER: builtins.int
    ENABLE_PARTITIONWISE_JOIN_FIELD_NUMBER: builtins.int
    JIT_FIELD_NUMBER: builtins.int
    MAX_PARALLEL_MAINTENANCE_WORKERS_FIELD_NUMBER: builtins.int
    PARALLEL_LEADER_PARTICIPATION_FIELD_NUMBER: builtins.int
    VACUUM_CLEANUP_INDEX_SCALE_FACTOR_FIELD_NUMBER: builtins.int
    LOG_TRANSACTION_SAMPLE_RATE_FIELD_NUMBER: builtins.int
    PLAN_CACHE_MODE_FIELD_NUMBER: builtins.int
    EFFECTIVE_IO_CONCURRENCY_FIELD_NUMBER: builtins.int
    EFFECTIVE_CACHE_SIZE_FIELD_NUMBER: builtins.int
    SHARED_PRELOAD_LIBRARIES_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_MIN_DURATION_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_ANALYZE_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_BUFFERS_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_TIMING_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_TRIGGERS_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_VERBOSE_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_NESTED_STATEMENTS_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_SAMPLE_RATE_FIELD_NUMBER: builtins.int
    PG_HINT_PLAN_ENABLE_HINT_FIELD_NUMBER: builtins.int
    PG_HINT_PLAN_ENABLE_HINT_TABLE_FIELD_NUMBER: builtins.int
    PG_HINT_PLAN_DEBUG_PRINT_FIELD_NUMBER: builtins.int
    PG_HINT_PLAN_MESSAGE_LEVEL_FIELD_NUMBER: builtins.int
    PG_QUALSTATS_ENABLED_FIELD_NUMBER: builtins.int
    PG_QUALSTATS_TRACK_CONSTANTS_FIELD_NUMBER: builtins.int
    PG_QUALSTATS_MAX_FIELD_NUMBER: builtins.int
    PG_QUALSTATS_RESOLVE_OIDS_FIELD_NUMBER: builtins.int
    PG_QUALSTATS_SAMPLE_RATE_FIELD_NUMBER: builtins.int
    PLANTUNER_FIX_EMPTY_TABLE_FIELD_NUMBER: builtins.int
    MAX_STACK_DEPTH_FIELD_NUMBER: builtins.int
    GEQO_FIELD_NUMBER: builtins.int
    GEQO_THRESHOLD_FIELD_NUMBER: builtins.int
    GEQO_EFFORT_FIELD_NUMBER: builtins.int
    GEQO_POOL_SIZE_FIELD_NUMBER: builtins.int
    GEQO_GENERATIONS_FIELD_NUMBER: builtins.int
    GEQO_SELECTION_BIAS_FIELD_NUMBER: builtins.int
    GEQO_SEED_FIELD_NUMBER: builtins.int
    PG_TRGM_SIMILARITY_THRESHOLD_FIELD_NUMBER: builtins.int
    PG_TRGM_WORD_SIMILARITY_THRESHOLD_FIELD_NUMBER: builtins.int
    PG_TRGM_STRICT_WORD_SIMILARITY_THRESHOLD_FIELD_NUMBER: builtins.int
    MAX_STANDBY_ARCHIVE_DELAY_FIELD_NUMBER: builtins.int
    SESSION_DURATION_TIMEOUT_FIELD_NUMBER: builtins.int
    LOG_REPLICATION_COMMANDS_FIELD_NUMBER: builtins.int
    LOG_AUTOVACUUM_MIN_DURATION_FIELD_NUMBER: builtins.int
    PASSWORD_ENCRYPTION_FIELD_NUMBER: builtins.int
    wal_level: global___PostgresqlConfig12_1C.WalLevel.ValueType
    synchronous_commit: global___PostgresqlConfig12_1C.SynchronousCommit.ValueType
    constraint_exclusion: global___PostgresqlConfig12_1C.ConstraintExclusion.ValueType
    force_parallel_mode: global___PostgresqlConfig12_1C.ForceParallelMode.ValueType
    client_min_messages: global___PostgresqlConfig12_1C.LogLevel.ValueType
    log_min_messages: global___PostgresqlConfig12_1C.LogLevel.ValueType
    log_min_error_statement: global___PostgresqlConfig12_1C.LogLevel.ValueType
    log_error_verbosity: global___PostgresqlConfig12_1C.LogErrorVerbosity.ValueType
    log_statement: global___PostgresqlConfig12_1C.LogStatement.ValueType
    search_path: builtins.str
    default_transaction_isolation: global___PostgresqlConfig12_1C.TransactionIsolation.ValueType
    bytea_output: global___PostgresqlConfig12_1C.ByteaOutput.ValueType
    xmlbinary: global___PostgresqlConfig12_1C.XmlBinary.ValueType
    xmloption: global___PostgresqlConfig12_1C.XmlOption.ValueType
    backslash_quote: global___PostgresqlConfig12_1C.BackslashQuote.ValueType
    timezone: builtins.str
    plan_cache_mode: global___PostgresqlConfig12_1C.PlanCacheMode.ValueType
    pg_hint_plan_debug_print: global___PostgresqlConfig12_1C.PgHintPlanDebugPrint.ValueType
    pg_hint_plan_message_level: global___PostgresqlConfig12_1C.LogLevel.ValueType
    password_encryption: global___PostgresqlConfig12_1C.PasswordEncryption.ValueType
    """A default value for `` user_password_encryption `` user-level setting, if it not specified for new users. Possible values are `` PASSWORD_ENCRYPTION_MD5 `` or `` PASSWORD_ENCRYPTION_SCRAM_SHA_256 ``. The default is `` PASSWORD_ENCRYPTION_MD5 ``."""
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def temp_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def work_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def maintenance_work_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def autovacuum_work_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def temp_file_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def vacuum_cost_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def vacuum_cost_page_hit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def vacuum_cost_page_miss(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def vacuum_cost_page_dirty(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def vacuum_cost_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def bgwriter_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def bgwriter_lru_maxpages(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def bgwriter_lru_multiplier(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def bgwriter_flush_after(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes"""

    @property
    def backend_flush_after(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes"""

    @property
    def old_snapshot_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def checkpoint_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def checkpoint_completion_target(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def checkpoint_flush_after(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes"""

    @property
    def max_wal_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def min_wal_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def max_standby_streaming_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def default_statistics_target(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cursor_tuple_fraction(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def from_collapse_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def join_collapse_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def log_min_duration_statement(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def log_checkpoints(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_connections(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_disconnections(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_duration(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_lock_waits(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_temp_files(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def row_security(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def statement_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def lock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def idle_in_transaction_session_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def gin_pending_list_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def deadlock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def max_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_pred_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def array_nulls(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def default_with_oids(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def escape_string_warning(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def lo_compat_privileges(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def operator_precedence_warning(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def quote_all_identifiers(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def standard_conforming_strings(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def synchronize_seqscans(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def transform_null_equals(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def exit_on_error(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def seq_page_cost(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def random_page_cost(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def autovacuum_max_workers(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def autovacuum_vacuum_cost_delay(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def autovacuum_vacuum_cost_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def autovacuum_naptime(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def archive_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def track_activity_query_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def online_analyze_enable(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_bitmapscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_hashagg(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_hashjoin(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_indexscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_indexonlyscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_material(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_mergejoin(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_nestloop(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_seqscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_sort(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_tidscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def max_worker_processes(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_parallel_workers(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_parallel_workers_per_gather(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def autovacuum_vacuum_scale_factor(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def autovacuum_analyze_scale_factor(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def default_transaction_read_only(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_parallel_append(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_parallel_hash(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_partition_pruning(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_partitionwise_aggregate(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_partitionwise_join(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def jit(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def max_parallel_maintenance_workers(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parallel_leader_participation(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def vacuum_cleanup_index_scale_factor(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def log_transaction_sample_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def effective_io_concurrency(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def effective_cache_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def shared_preload_libraries(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType]: ...
    @property
    def auto_explain_log_min_duration(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def auto_explain_log_analyze(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_log_buffers(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_log_timing(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_log_triggers(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_log_verbose(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_log_nested_statements(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_sample_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def pg_hint_plan_enable_hint(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def pg_hint_plan_enable_hint_table(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def pg_qualstats_enabled(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def pg_qualstats_track_constants(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def pg_qualstats_max(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def pg_qualstats_resolve_oids(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def pg_qualstats_sample_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def plantuner_fix_empty_table(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def max_stack_depth(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def geqo(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """enable Genetic Query Optimizer, by default is on"""

    @property
    def geqo_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of tables to use geqo, default is 12"""

    @property
    def geqo_effort(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """tradeoff between planning time and query plan quality, default is 5"""

    @property
    def geqo_pool_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """number of individuals in the genetic population, useful values are typically 100 to 1000; default - 0 - choose based on based on geqo_effort"""

    @property
    def geqo_generations(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """the number of generations used by GEQO, useful values are in the same range as the pool size"""

    @property
    def geqo_selection_bias(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """selective pressure within the population"""

    @property
    def geqo_seed(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """initial value of the random number generator used by GEQO"""

    @property
    def pg_trgm_similarity_threshold(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def pg_trgm_word_similarity_threshold(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def pg_trgm_strict_word_similarity_threshold(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def max_standby_archive_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def session_duration_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Terminate any session that exceeds the designated timeout, specified in milliseconds. If a timeout is not specified, the default session timeout is set to 12 hours. To disable it, specify a value of 0."""

    @property
    def log_replication_commands(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_autovacuum_min_duration(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds. The default is 1000 (1 sec)."""

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temp_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        work_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        maintenance_work_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        autovacuum_work_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temp_file_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_cost_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_cost_page_hit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_cost_page_miss: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_cost_page_dirty: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_cost_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bgwriter_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bgwriter_lru_maxpages: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bgwriter_lru_multiplier: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        bgwriter_flush_after: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        backend_flush_after: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        old_snapshot_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        wal_level: global___PostgresqlConfig12_1C.WalLevel.ValueType = ...,
        synchronous_commit: global___PostgresqlConfig12_1C.SynchronousCommit.ValueType = ...,
        checkpoint_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        checkpoint_completion_target: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        checkpoint_flush_after: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_wal_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        min_wal_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_standby_streaming_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        default_statistics_target: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        constraint_exclusion: global___PostgresqlConfig12_1C.ConstraintExclusion.ValueType = ...,
        cursor_tuple_fraction: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        from_collapse_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        join_collapse_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        force_parallel_mode: global___PostgresqlConfig12_1C.ForceParallelMode.ValueType = ...,
        client_min_messages: global___PostgresqlConfig12_1C.LogLevel.ValueType = ...,
        log_min_messages: global___PostgresqlConfig12_1C.LogLevel.ValueType = ...,
        log_min_error_statement: global___PostgresqlConfig12_1C.LogLevel.ValueType = ...,
        log_min_duration_statement: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_checkpoints: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_connections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_disconnections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_duration: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_error_verbosity: global___PostgresqlConfig12_1C.LogErrorVerbosity.ValueType = ...,
        log_lock_waits: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_statement: global___PostgresqlConfig12_1C.LogStatement.ValueType = ...,
        log_temp_files: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        search_path: builtins.str = ...,
        row_security: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        default_transaction_isolation: global___PostgresqlConfig12_1C.TransactionIsolation.ValueType = ...,
        statement_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_session_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bytea_output: global___PostgresqlConfig12_1C.ByteaOutput.ValueType = ...,
        xmlbinary: global___PostgresqlConfig12_1C.XmlBinary.ValueType = ...,
        xmloption: global___PostgresqlConfig12_1C.XmlOption.ValueType = ...,
        gin_pending_list_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        deadlock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_pred_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        array_nulls: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        backslash_quote: global___PostgresqlConfig12_1C.BackslashQuote.ValueType = ...,
        default_with_oids: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        escape_string_warning: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        lo_compat_privileges: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        operator_precedence_warning: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        quote_all_identifiers: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        standard_conforming_strings: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        synchronize_seqscans: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        transform_null_equals: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        exit_on_error: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        seq_page_cost: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        random_page_cost: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        autovacuum_max_workers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        autovacuum_vacuum_cost_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        autovacuum_vacuum_cost_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        autovacuum_naptime: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        archive_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        track_activity_query_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        online_analyze_enable: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_bitmapscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_hashagg: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_hashjoin: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_indexscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_indexonlyscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_material: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_mergejoin: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_nestloop: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_seqscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_sort: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_tidscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_worker_processes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_parallel_workers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_parallel_workers_per_gather: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        autovacuum_vacuum_scale_factor: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        autovacuum_analyze_scale_factor: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        default_transaction_read_only: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        timezone: builtins.str = ...,
        enable_parallel_append: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_parallel_hash: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_partition_pruning: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_partitionwise_aggregate: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_partitionwise_join: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        jit: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_parallel_maintenance_workers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        parallel_leader_participation: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        vacuum_cleanup_index_scale_factor: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        log_transaction_sample_rate: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        plan_cache_mode: global___PostgresqlConfig12_1C.PlanCacheMode.ValueType = ...,
        effective_io_concurrency: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        effective_cache_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        shared_preload_libraries: collections.abc.Iterable[global___PostgresqlConfig12_1C.SharedPreloadLibraries.ValueType] | None = ...,
        auto_explain_log_min_duration: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        auto_explain_log_analyze: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_log_buffers: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_log_timing: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_log_triggers: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_log_verbose: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_log_nested_statements: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_sample_rate: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        pg_hint_plan_enable_hint: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pg_hint_plan_enable_hint_table: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pg_hint_plan_debug_print: global___PostgresqlConfig12_1C.PgHintPlanDebugPrint.ValueType = ...,
        pg_hint_plan_message_level: global___PostgresqlConfig12_1C.LogLevel.ValueType = ...,
        pg_qualstats_enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pg_qualstats_track_constants: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pg_qualstats_max: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        pg_qualstats_resolve_oids: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pg_qualstats_sample_rate: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        plantuner_fix_empty_table: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_stack_depth: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        geqo: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        geqo_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        geqo_effort: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        geqo_pool_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        geqo_generations: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        geqo_selection_bias: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        geqo_seed: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        pg_trgm_similarity_threshold: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        pg_trgm_word_similarity_threshold: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        pg_trgm_strict_word_similarity_threshold: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        max_standby_archive_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        session_duration_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_replication_commands: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_autovacuum_min_duration: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        password_encryption: global___PostgresqlConfig12_1C.PasswordEncryption.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["archive_timeout", b"archive_timeout", "array_nulls", b"array_nulls", "auto_explain_log_analyze", b"auto_explain_log_analyze", "auto_explain_log_buffers", b"auto_explain_log_buffers", "auto_explain_log_min_duration", b"auto_explain_log_min_duration", "auto_explain_log_nested_statements", b"auto_explain_log_nested_statements", "auto_explain_log_timing", b"auto_explain_log_timing", "auto_explain_log_triggers", b"auto_explain_log_triggers", "auto_explain_log_verbose", b"auto_explain_log_verbose", "auto_explain_sample_rate", b"auto_explain_sample_rate", "autovacuum_analyze_scale_factor", b"autovacuum_analyze_scale_factor", "autovacuum_max_workers", b"autovacuum_max_workers", "autovacuum_naptime", b"autovacuum_naptime", "autovacuum_vacuum_cost_delay", b"autovacuum_vacuum_cost_delay", "autovacuum_vacuum_cost_limit", b"autovacuum_vacuum_cost_limit", "autovacuum_vacuum_scale_factor", b"autovacuum_vacuum_scale_factor", "autovacuum_work_mem", b"autovacuum_work_mem", "backend_flush_after", b"backend_flush_after", "bgwriter_delay", b"bgwriter_delay", "bgwriter_flush_after", b"bgwriter_flush_after", "bgwriter_lru_maxpages", b"bgwriter_lru_maxpages", "bgwriter_lru_multiplier", b"bgwriter_lru_multiplier", "checkpoint_completion_target", b"checkpoint_completion_target", "checkpoint_flush_after", b"checkpoint_flush_after", "checkpoint_timeout", b"checkpoint_timeout", "cursor_tuple_fraction", b"cursor_tuple_fraction", "deadlock_timeout", b"deadlock_timeout", "default_statistics_target", b"default_statistics_target", "default_transaction_read_only", b"default_transaction_read_only", "default_with_oids", b"default_with_oids", "effective_cache_size", b"effective_cache_size", "effective_io_concurrency", b"effective_io_concurrency", "enable_bitmapscan", b"enable_bitmapscan", "enable_hashagg", b"enable_hashagg", "enable_hashjoin", b"enable_hashjoin", "enable_indexonlyscan", b"enable_indexonlyscan", "enable_indexscan", b"enable_indexscan", "enable_material", b"enable_material", "enable_mergejoin", b"enable_mergejoin", "enable_nestloop", b"enable_nestloop", "enable_parallel_append", b"enable_parallel_append", "enable_parallel_hash", b"enable_parallel_hash", "enable_partition_pruning", b"enable_partition_pruning", "enable_partitionwise_aggregate", b"enable_partitionwise_aggregate", "enable_partitionwise_join", b"enable_partitionwise_join", "enable_seqscan", b"enable_seqscan", "enable_sort", b"enable_sort", "enable_tidscan", b"enable_tidscan", "escape_string_warning", b"escape_string_warning", "exit_on_error", b"exit_on_error", "from_collapse_limit", b"from_collapse_limit", "geqo", b"geqo", "geqo_effort", b"geqo_effort", "geqo_generations", b"geqo_generations", "geqo_pool_size", b"geqo_pool_size", "geqo_seed", b"geqo_seed", "geqo_selection_bias", b"geqo_selection_bias", "geqo_threshold", b"geqo_threshold", "gin_pending_list_limit", b"gin_pending_list_limit", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "jit", b"jit", "join_collapse_limit", b"join_collapse_limit", "lo_compat_privileges", b"lo_compat_privileges", "lock_timeout", b"lock_timeout", "log_autovacuum_min_duration", b"log_autovacuum_min_duration", "log_checkpoints", b"log_checkpoints", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_duration", b"log_duration", "log_lock_waits", b"log_lock_waits", "log_min_duration_statement", b"log_min_duration_statement", "log_replication_commands", b"log_replication_commands", "log_temp_files", b"log_temp_files", "log_transaction_sample_rate", b"log_transaction_sample_rate", "maintenance_work_mem", b"maintenance_work_mem", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_parallel_maintenance_workers", b"max_parallel_maintenance_workers", "max_parallel_workers", b"max_parallel_workers", "max_parallel_workers_per_gather", b"max_parallel_workers_per_gather", "max_pred_locks_per_transaction", b"max_pred_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_stack_depth", b"max_stack_depth", "max_standby_archive_delay", b"max_standby_archive_delay", "max_standby_streaming_delay", b"max_standby_streaming_delay", "max_wal_size", b"max_wal_size", "max_worker_processes", b"max_worker_processes", "min_wal_size", b"min_wal_size", "old_snapshot_threshold", b"old_snapshot_threshold", "online_analyze_enable", b"online_analyze_enable", "operator_precedence_warning", b"operator_precedence_warning", "parallel_leader_participation", b"parallel_leader_participation", "pg_hint_plan_enable_hint", b"pg_hint_plan_enable_hint", "pg_hint_plan_enable_hint_table", b"pg_hint_plan_enable_hint_table", "pg_qualstats_enabled", b"pg_qualstats_enabled", "pg_qualstats_max", b"pg_qualstats_max", "pg_qualstats_resolve_oids", b"pg_qualstats_resolve_oids", "pg_qualstats_sample_rate", b"pg_qualstats_sample_rate", "pg_qualstats_track_constants", b"pg_qualstats_track_constants", "pg_trgm_similarity_threshold", b"pg_trgm_similarity_threshold", "pg_trgm_strict_word_similarity_threshold", b"pg_trgm_strict_word_similarity_threshold", "pg_trgm_word_similarity_threshold", b"pg_trgm_word_similarity_threshold", "plantuner_fix_empty_table", b"plantuner_fix_empty_table", "quote_all_identifiers", b"quote_all_identifiers", "random_page_cost", b"random_page_cost", "row_security", b"row_security", "seq_page_cost", b"seq_page_cost", "session_duration_timeout", b"session_duration_timeout", "shared_buffers", b"shared_buffers", "standard_conforming_strings", b"standard_conforming_strings", "statement_timeout", b"statement_timeout", "synchronize_seqscans", b"synchronize_seqscans", "temp_buffers", b"temp_buffers", "temp_file_limit", b"temp_file_limit", "track_activity_query_size", b"track_activity_query_size", "transform_null_equals", b"transform_null_equals", "vacuum_cleanup_index_scale_factor", b"vacuum_cleanup_index_scale_factor", "vacuum_cost_delay", b"vacuum_cost_delay", "vacuum_cost_limit", b"vacuum_cost_limit", "vacuum_cost_page_dirty", b"vacuum_cost_page_dirty", "vacuum_cost_page_hit", b"vacuum_cost_page_hit", "vacuum_cost_page_miss", b"vacuum_cost_page_miss", "work_mem", b"work_mem"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["archive_timeout", b"archive_timeout", "array_nulls", b"array_nulls", "auto_explain_log_analyze", b"auto_explain_log_analyze", "auto_explain_log_buffers", b"auto_explain_log_buffers", "auto_explain_log_min_duration", b"auto_explain_log_min_duration", "auto_explain_log_nested_statements", b"auto_explain_log_nested_statements", "auto_explain_log_timing", b"auto_explain_log_timing", "auto_explain_log_triggers", b"auto_explain_log_triggers", "auto_explain_log_verbose", b"auto_explain_log_verbose", "auto_explain_sample_rate", b"auto_explain_sample_rate", "autovacuum_analyze_scale_factor", b"autovacuum_analyze_scale_factor", "autovacuum_max_workers", b"autovacuum_max_workers", "autovacuum_naptime", b"autovacuum_naptime", "autovacuum_vacuum_cost_delay", b"autovacuum_vacuum_cost_delay", "autovacuum_vacuum_cost_limit", b"autovacuum_vacuum_cost_limit", "autovacuum_vacuum_scale_factor", b"autovacuum_vacuum_scale_factor", "autovacuum_work_mem", b"autovacuum_work_mem", "backend_flush_after", b"backend_flush_after", "backslash_quote", b"backslash_quote", "bgwriter_delay", b"bgwriter_delay", "bgwriter_flush_after", b"bgwriter_flush_after", "bgwriter_lru_maxpages", b"bgwriter_lru_maxpages", "bgwriter_lru_multiplier", b"bgwriter_lru_multiplier", "bytea_output", b"bytea_output", "checkpoint_completion_target", b"checkpoint_completion_target", "checkpoint_flush_after", b"checkpoint_flush_after", "checkpoint_timeout", b"checkpoint_timeout", "client_min_messages", b"client_min_messages", "constraint_exclusion", b"constraint_exclusion", "cursor_tuple_fraction", b"cursor_tuple_fraction", "deadlock_timeout", b"deadlock_timeout", "default_statistics_target", b"default_statistics_target", "default_transaction_isolation", b"default_transaction_isolation", "default_transaction_read_only", b"default_transaction_read_only", "default_with_oids", b"default_with_oids", "effective_cache_size", b"effective_cache_size", "effective_io_concurrency", b"effective_io_concurrency", "enable_bitmapscan", b"enable_bitmapscan", "enable_hashagg", b"enable_hashagg", "enable_hashjoin", b"enable_hashjoin", "enable_indexonlyscan", b"enable_indexonlyscan", "enable_indexscan", b"enable_indexscan", "enable_material", b"enable_material", "enable_mergejoin", b"enable_mergejoin", "enable_nestloop", b"enable_nestloop", "enable_parallel_append", b"enable_parallel_append", "enable_parallel_hash", b"enable_parallel_hash", "enable_partition_pruning", b"enable_partition_pruning", "enable_partitionwise_aggregate", b"enable_partitionwise_aggregate", "enable_partitionwise_join", b"enable_partitionwise_join", "enable_seqscan", b"enable_seqscan", "enable_sort", b"enable_sort", "enable_tidscan", b"enable_tidscan", "escape_string_warning", b"escape_string_warning", "exit_on_error", b"exit_on_error", "force_parallel_mode", b"force_parallel_mode", "from_collapse_limit", b"from_collapse_limit", "geqo", b"geqo", "geqo_effort", b"geqo_effort", "geqo_generations", b"geqo_generations", "geqo_pool_size", b"geqo_pool_size", "geqo_seed", b"geqo_seed", "geqo_selection_bias", b"geqo_selection_bias", "geqo_threshold", b"geqo_threshold", "gin_pending_list_limit", b"gin_pending_list_limit", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "jit", b"jit", "join_collapse_limit", b"join_collapse_limit", "lo_compat_privileges", b"lo_compat_privileges", "lock_timeout", b"lock_timeout", "log_autovacuum_min_duration", b"log_autovacuum_min_duration", "log_checkpoints", b"log_checkpoints", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_duration", b"log_duration", "log_error_verbosity", b"log_error_verbosity", "log_lock_waits", b"log_lock_waits", "log_min_duration_statement", b"log_min_duration_statement", "log_min_error_statement", b"log_min_error_statement", "log_min_messages", b"log_min_messages", "log_replication_commands", b"log_replication_commands", "log_statement", b"log_statement", "log_temp_files", b"log_temp_files", "log_transaction_sample_rate", b"log_transaction_sample_rate", "maintenance_work_mem", b"maintenance_work_mem", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_parallel_maintenance_workers", b"max_parallel_maintenance_workers", "max_parallel_workers", b"max_parallel_workers", "max_parallel_workers_per_gather", b"max_parallel_workers_per_gather", "max_pred_locks_per_transaction", b"max_pred_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_stack_depth", b"max_stack_depth", "max_standby_archive_delay", b"max_standby_archive_delay", "max_standby_streaming_delay", b"max_standby_streaming_delay", "max_wal_size", b"max_wal_size", "max_worker_processes", b"max_worker_processes", "min_wal_size", b"min_wal_size", "old_snapshot_threshold", b"old_snapshot_threshold", "online_analyze_enable", b"online_analyze_enable", "operator_precedence_warning", b"operator_precedence_warning", "parallel_leader_participation", b"parallel_leader_participation", "password_encryption", b"password_encryption", "pg_hint_plan_debug_print", b"pg_hint_plan_debug_print", "pg_hint_plan_enable_hint", b"pg_hint_plan_enable_hint", "pg_hint_plan_enable_hint_table", b"pg_hint_plan_enable_hint_table", "pg_hint_plan_message_level", b"pg_hint_plan_message_level", "pg_qualstats_enabled", b"pg_qualstats_enabled", "pg_qualstats_max", b"pg_qualstats_max", "pg_qualstats_resolve_oids", b"pg_qualstats_resolve_oids", "pg_qualstats_sample_rate", b"pg_qualstats_sample_rate", "pg_qualstats_track_constants", b"pg_qualstats_track_constants", "pg_trgm_similarity_threshold", b"pg_trgm_similarity_threshold", "pg_trgm_strict_word_similarity_threshold", b"pg_trgm_strict_word_similarity_threshold", "pg_trgm_word_similarity_threshold", b"pg_trgm_word_similarity_threshold", "plan_cache_mode", b"plan_cache_mode", "plantuner_fix_empty_table", b"plantuner_fix_empty_table", "quote_all_identifiers", b"quote_all_identifiers", "random_page_cost", b"random_page_cost", "row_security", b"row_security", "search_path", b"search_path", "seq_page_cost", b"seq_page_cost", "session_duration_timeout", b"session_duration_timeout", "shared_buffers", b"shared_buffers", "shared_preload_libraries", b"shared_preload_libraries", "standard_conforming_strings", b"standard_conforming_strings", "statement_timeout", b"statement_timeout", "synchronize_seqscans", b"synchronize_seqscans", "synchronous_commit", b"synchronous_commit", "temp_buffers", b"temp_buffers", "temp_file_limit", b"temp_file_limit", "timezone", b"timezone", "track_activity_query_size", b"track_activity_query_size", "transform_null_equals", b"transform_null_equals", "vacuum_cleanup_index_scale_factor", b"vacuum_cleanup_index_scale_factor", "vacuum_cost_delay", b"vacuum_cost_delay", "vacuum_cost_limit", b"vacuum_cost_limit", "vacuum_cost_page_dirty", b"vacuum_cost_page_dirty", "vacuum_cost_page_hit", b"vacuum_cost_page_hit", "vacuum_cost_page_miss", b"vacuum_cost_page_miss", "wal_level", b"wal_level", "work_mem", b"work_mem", "xmlbinary", b"xmlbinary", "xmloption", b"xmloption"]) -> None: ...

global___PostgresqlConfig12_1C = PostgresqlConfig12_1C

@typing.final
class PostgresqlConfigSet12_1C(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___PostgresqlConfig12_1C:
        """Effective settings for a PostgreSQL 12 1C cluster (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___PostgresqlConfig12_1C:
        """User-defined settings for a PostgreSQL 12 1C cluster."""

    @property
    def default_config(self) -> global___PostgresqlConfig12_1C:
        """Default configuration for a PostgreSQL 12 1C cluster."""

    def __init__(
        self,
        *,
        effective_config: global___PostgresqlConfig12_1C | None = ...,
        user_config: global___PostgresqlConfig12_1C | None = ...,
        default_config: global___PostgresqlConfig12_1C | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___PostgresqlConfigSet12_1C = PostgresqlConfigSet12_1C
